DEC Special Graphics - Wikipedia

# DEC Special Graphics

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

DEC Special Graphics
A modified DEC Special Graphics set (with additional fill blocks and arrows, and without the control pictures) accessed in a Linux terminal using Shift Out.
Alias(es) | IBM-1090
Based on | ASCII
Other related encoding(s) | PETSCII

DEC Special Graphics[1] is a 7-bit character set developed by Digital Equipment Corporation. This was used very often to draw boxes on the VT100 video terminal and the many emulators, and used by bulletin board software. The designation escape sequence `ESC ( 0` (hexadecimal `1B 28 30`) switched the codes for lower-case ASCII letters to draw this set, and the sequence `ESC ( B` (hexadecimal `1B 28 42`) switched back.[2] IBM calls it Code page 1090.[3]

## Character set[edit]

DEC Special[1][3]
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
5_ 80 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  | NBSP 00A0
6_ 96 | ◆ 25C6 | ▒ 2592 | ␉ 2409 | ␌ 240C | ␍ 240D | ␊ 240A | ° 00B0 | ± 00B1 | ␤ 2424 | ␋ 240B | ┘ 2518 | ┐ 2510 | ┌ 250C | └ 2514 | ┼ 253C | ⎺ 23BA
7_ 112 | ⎻ 23BB | ─ 2500 | ⎼ 23BC | ⎽ 23BD | ├ 251C | ┤ 2524 | ┴ 2534 | ┬ 252C | │ 2502 | ≤ 2264 | ≥ 2265 | π 03C0 | ≠ 2260 | £ 00A3 | · 00B7 |

Letter Number Punctuation Symbol Other Same as ASCII (not shown)

## See also[edit]

- DEC Multinational Character Set (MCS)
- DEC National Replacement Character Set (NRCS)
- DEC Technical Character Set
- DEC VT100
- Box-drawing character

## References[edit]

1. ^ a b
   Digital (1984). "Table 2-4: DEC Special Graphics Character Set". VT220 Programmer Reference Manual (2nd ed.).
2. ^ Mascheck, Sven; Le Breton, Stefan; Hamilton, Richard L. "About the 'alternate linedrawing character set'". ~sven_mascheck/.
3. ^ a b IBM. Code Page 01090 (PDF). Archived from the original (PDF) on 2015-07-08. Retrieved 2020-01-08.

Retrieved from "https://en.wikipedia.org/w/index.php?title=DEC_Special_Graphics&oldid=1026188521"
Categories:

- Character sets
- Digital Equipment Corporation